//--------------------------- BASIC PROPERTIES ------------------------------

#include "include\\Warnings.fxh"

float4x4 World;
float4x4 View;
float4x4 Projection;
float4x4 WorldInverseTranspose;

static const int MAX_MATRICES = 35;
float4x4 WorldMatrixArray[MAX_MATRICES] : WORLDMATRIXARRAY;
int numBoneInfluences = 2;

bool Skinning;
bool SelfShadows;

float3 DiffuseLightDirection;
float4 DiffuseColor = float4(1, 1, 1, 1);
float DiffuseIntensity = 1.0;
float4 LineColor = float4(0, 0, 0, 1);
float LineThickness;

texture2D Texture;
 
// The texture sampler, which will get the texture color
SamplerState textureSampler = sampler_state
{
    Texture = (Texture);
    Filter = COMPARISON_MIN_MAG_LINEAR_MIP_POINT;
    AddressU = Clamp;
    AddressV = Clamp;
};
 
//--------------------------- DATA STRUCTURES ------------------------------
struct VS_OUTPUT
{
    float4 Position : POSITION0;
    float2 TextureCoordinate : TEXCOORD0;
    float3 Normal : TEXCOORD1;
};

//--------------------------- SHADERS ------------------------------
 
// The pixel shader that does cel shading.  Basically, it calculates
// the color like is should, and then it discretizes the color into
// one of four colors.
float4 main(VS_OUTPUT input) : SV_Target0
{
    // Calculate diffuse light amount
    float intensity = dot(normalize(DiffuseLightDirection), input.Normal);
    if(intensity < 0)
        intensity = 0;
	if(intensity > 1)
        intensity = 1;
 
    // Calculate what would normally be the final color, including texturing and diffuse lighting
    float4 color = Texture.Sample(textureSampler, input.TextureCoordinate) * DiffuseColor * DiffuseIntensity;
    color.a = 1;
 
	//return color;
    // Discretize the intensity, based on a few cutoff points
	if(SelfShadows)
	{
		if (intensity > 0.35)
        color = float4(1,1,1,1) * color;
		/*else if (intensity > 0.2)
			color = float4(0.7,0.7,0.7,1) * color;*/
		else //if (intensity > 0.05)
			color = float4(0.65,0.65,0.65,1) * color;
		/*else
			color = float4(0.1,0.1,0.1,1) * color;*/
	}
	else
		color = float4(1,1,1,1) * color;

    return color;
}